@@ -7,7 +7,7 @@ RDF::Trine::Iterator - Stream (iterator) class for SPARQL query results
 
 =head1 VERSION
 
-This document describes RDF::Trine::Iterator version 0.132.
+This document describes RDF::Trine::Iterator version 0.133.
 
 =head1 SYNOPSIS
 
@@ -30,7 +30,6 @@ use strict;
 use warnings;
 no warnings 'redefine';
 
-use JSON;
 use Data::Dumper;
 use Log::Log4perl;
 use Carp qw(carp);
@@ -39,10 +38,11 @@ use Scalar::Util qw(blessed reftype refaddr);
 use XML::SAX;
 use RDF::Trine::Node;
 use RDF::Trine::Iterator::SAXHandler;
+use RDF::Trine::Iterator::JSONHandler;
 
 our ($VERSION, @ISA, @EXPORT_OK);
 BEGIN {
-	$VERSION	= '0.132';
+	$VERSION	= '0.133';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
@@ -164,7 +164,7 @@ sub to_string {
 	}
 }
 
-=item C<from_string ( $xml )>
+=item C<< from_string ( $xml ) >>
 
 Returns a new iterator using the supplied XML in the SPARQL XML Results format.
 
@@ -185,6 +185,17 @@ sub from_string {
 	return $iter;
 }
 
+=item C<< from_json ( $json ) >>
+
+=cut
+
+sub from_json {
+	my $class	= shift;
+	my $json	= shift;
+	my $p		= RDF::Trine::Iterator::JSONHandler->new();
+	return $p->parse( $json );
+}
+
 
 =item C<< next_result >>
 
