@@ -7,20 +7,13 @@ RDF::Trine::Iterator::JSONHandler - JSON Handler for parsing SPARQL JSON Results
 
 =head1 VERSION
 
-This document describes RDF::Trine::Iterator::JSONHandler version 0.999_02
-
-=head1 STATUS
-
-This module's API and functionality should be considered unstable.
-In the future, this module may change in backwards-incompatible ways,
-or be removed entirely. If you need functionality that this module provides,
-please L<get in touch|http://www.perlrdf.org/>.
+This document describes RDF::Trine::Iterator::JSONHandler version 0.133
 
 =head1 SYNOPSIS
 
- use RDF::Trine::Iterator::JSONHandler;
- my $handler = RDF::Trine::Iterator::JSONHandler->new();
- my $iter = $handler->parse( $json );
+    use RDF::Trine::Iterator::JSONHandler;
+    my $handler = RDF::Trine::Iterator::SAXHandler->new();
+    my $iter = $handler->parse( $json );
 
 =head1 METHODS
 
@@ -40,7 +33,7 @@ use RDF::Trine::VariableBindings;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.999_02';
+	$VERSION	= '0.133';
 }
 
 =item C<< new >>
@@ -51,8 +44,7 @@ Returns a new JSON SPARQL Results parser object.
 
 sub new {
 	my $class	= shift;
-	my %args	= %{ shift || {} };
-	return bless(\%args, $class);
+	return bless({}, $class);
 }
 
 =item C<< parse ( $json ) >>
@@ -95,9 +87,6 @@ sub parse {
 					} elsif ($type eq 'typed-literal') {
 						my $data	= $value->{value};
 						my $dt		= $value->{datatype};
-						if ($self->{canonicalize}) {
-							$data	= RDF::Trine::Node::Literal->canonicalize_literal_value( $data, $dt, 0 );
-						}
 						$data{ $v }	= RDF::Trine::Node::Literal->new( $data, undef, $dt );
 					} else {
 						warn Dumper($data, $b);
@@ -118,18 +107,13 @@ __END__
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests to through the GitHub web interface
-at L<https://github.com/kasei/perlrdf/issues>.
-
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2006-2010 Gregory Todd Williams. All rights reserved. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
