@@ -8,7 +8,7 @@ RDF::Trine::NamespaceMap - Collection of Namespaces
 
 =head1 VERSION
 
-This document describes RDF::Trine::NamespaceMap version 0.999_02
+This document describes RDF::Trine::NamespaceMap version 0.133
 
 =head1 SYNOPSIS
 
@@ -43,7 +43,7 @@ use Data::Dumper;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.999_02';
+	$VERSION	= '0.133';
 }
 
 ######################################################################
@@ -130,7 +130,7 @@ sub uri {
 	my $abbr	= shift;
 	my $ns;
 	my $local	= "";
-	if ($abbr =~ m/^([^:]*):(.*)$/) {
+	if ($abbr =~ m/^([^:]+):(.*)$/) {
 		$ns	= $self->{ $1 };
 		$local	= $2;
 	} else {
@@ -172,8 +172,8 @@ The method names 'new' and 'uri' are also forbidden.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to through the GitHub web interface
-at L<https://github.com/kasei/perlrdf/issues>.
+Please report any bugs or feature requests to
+C<< <gwilliams@cpan.org> >>.
 
 =head1 AUTHOR
 
@@ -181,7 +181,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 Gregory Todd Williams. This
+Copyright (c) 2006-2010 Gregory Todd Williams. All rights reserved. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
