@@ -7,7 +7,7 @@ RDF::Trine::Node::Blank - RDF Node class for blank nodes
 
 =head1 VERSION
 
-This document describes RDF::Trine::Node::Blank version 0.132
+This document describes RDF::Trine::Node::Blank version 0.133
 
 =cut
 
@@ -26,11 +26,14 @@ use Carp qw(carp croak confess);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.132';
+	$VERSION	= '0.133';
 }
 
 ######################################################################
 
+use overload	'""'	=> sub { $_[0]->sse },
+			;
+
 =head1 METHODS
 
 Beyond the methods documented below, this class inherits methods from the
