@@ -7,7 +7,7 @@ RDF::Trine::Parser::Redland - RDFa Parser
 
 =head1 VERSION
 
-This document describes RDF::Trine::Parser::RDFa version 0.132
+This document describes RDF::Trine::Parser::RDFa version 0.133
 
 =head1 SYNOPSIS
 
@@ -85,7 +85,7 @@ BEGIN {
 				],
 	);
 	
-	$VERSION	= '0.132';
+	$VERSION	= '0.133';
 	for my $format (keys %FORMATS) {
 		$RDF::Trine::Parser::parser_names{$format} = $FORMATS{$format}[0];
 		$RDF::Trine::Parser::format_uris{ $FORMATS{$format}[1] } = $FORMATS{$format}[0]
@@ -184,6 +184,14 @@ sub parse {
 
 		$stream->next;
 	}
+	
+	if (my $map = $self->{ namespaces }) {
+		my %seen	= $self->{parser}->namespaces_seen;
+		while (my ($ns, $uri) = each(%seen)) {
+			$map->add_mapping( $ns => $uri->as_string );
+		}
+	}
+	return;
 }
 
 package RDF::Trine::Parser::Redland::RDFXML;
