@@ -7,7 +7,7 @@ RDF::Trine::Serializer::RDFXML - RDF/XML Serializer
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::RDFXML version 0.132
+This document describes RDF::Trine::Serializer::RDFXML version 0.133
 
 =head1 SYNOPSIS
 
@@ -49,7 +49,7 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.132';
+	$VERSION	= '0.133';
 	$RDF::Trine::Serializer::serializer_names{ 'rdfxml' }	= __PACKAGE__;
 	$RDF::Trine::Serializer::format_uris{ 'http://www.w3.org/ns/formats/RDF_XML' }	= __PACKAGE__;
 	foreach my $type (qw(application/rdf+xml)) {
@@ -71,7 +71,13 @@ sub new {
 	my $self = bless( { namespaces => { 'http://www.w3.org/1999/02/22-rdf-syntax-ns#' => 'rdf' } }, $class);
 	if (my $ns = $args{namespaces}) {
 		my %ns		= %{ $ns };
-		my %nsmap	= reverse %ns;
+		my %nsmap;
+		while (my ($ns, $uri) = each(%ns)) {
+			for (1..2) {
+				$uri	= $uri->uri_value if (blessed($uri));
+			}
+			$nsmap{ $uri }	= $ns;
+		}
 		@{ $self->{namespaces} }{ keys %nsmap }	= values %nsmap;
 	}
 	if ($args{base}) {
@@ -177,8 +183,11 @@ sub _statements_same_subject_as_string {
 		my $prefix	= $namespaces{ $ns };
 		if ($o->isa('RDF::Trine::Node::Literal')) {
 			my $lv		= $o->literal_value;
-			$lv			=~ s/&/&amp;/g;
-			$lv			=~ s/</&lt;/g;
+			for ($lv) {
+				s/&/&amp;/g;
+				s/</&lt;/g;
+				s/"/&quot;/g;
+			}
 			my $lang	= $o->literal_value_language;
 			my $dt		= $o->literal_datatype;
 			my $tag	= join(':', $prefix, $ln);
@@ -191,9 +200,19 @@ sub _statements_same_subject_as_string {
 			}
 		} elsif ($o->isa('RDF::Trine::Node::Blank')) {
 			my $b	= $o->blank_identifier;
+			for ($b) {
+				s/&/&amp;/g;
+				s/</&lt;/g;
+				s/"/&quot;/g;
+			}
 			$string	.= qq[\t<${prefix}:$ln rdf:nodeID="$b"/>\n];
 		} else {
 			my $u	= $o->uri_value;
+			for ($u) {
+				s/&/&amp;/g;
+				s/</&lt;/g;
+				s/"/&quot;/g;
+			}
 			$string	.= qq[\t<${prefix}:$ln rdf:resource="$u"/>\n];
 		}
 	}
@@ -202,7 +221,13 @@ sub _statements_same_subject_as_string {
 	
 	# rdf namespace is already defined in the <rdf:RDF> tag, so ignore it here
 	my %seen	= %{ $self->{namespaces} };
-	my $ns	= join(' ', map { my $ns = $namespaces{$_}; qq[xmlns:${ns}="$_"] } sort { $namespaces{$a} cmp $namespaces{$b} } grep { not($seen{$_}) } (keys %namespaces));
+	my @ns;
+	foreach my $uri (sort { $namespaces{$a} cmp $namespaces{$b} } grep { not($seen{$_}) } (keys %namespaces)) {
+		my $ns	= $namespaces{$uri};
+		my $str	= ($ns eq '') ? qq[xmlns="$uri"] : qq[xmlns:${ns}="$uri"];
+		push(@ns, $str);
+	}
+	my $ns	= join(' ', @ns);
 	if ($ns) {
 		return qq[<rdf:Description ${ns} $id>\n] . $string;
 	} else {
@@ -265,7 +290,11 @@ sub _top_xmlns {
 	my @ns;
 	foreach my $v (@keys) {
 		my $k	= $namespaces->{$v};
-		push(@ns, qq[xmlns:$k="$v"]);
+		if (blessed($v)) {
+			$v	= $v->uri_value;
+		}
+		my $str	= ($k eq '') ? qq[xmlns="$v"] : qq[xmlns:$k="$v"];
+		push(@ns, $str);
 	}
 	my $ns		= join(' ', @ns);
 	return $ns;
